export_vst3

Macro export_vst3 

macro_rules! export_vst3 {
    () => { ... };
}
Exports an AUv2 entrypoint named GetPluginFactoryAUV2 that wraps a global CLAP entrypoint (clap_entry) exported from the resulting shared library. Currently it only reexports the first plugin available through the CLAP entrypoint, but this limitation might be lifted in the future.

Failure to export a CLAP entrypoint might result in linker errors or missing symbols.